<a id="types-aiobotocore-appstream"></a>

# types-aiobotocore-appstream

[![PyPI - types-aiobotocore-appstream](https://img.shields.io/pypi/v/types-aiobotocore-appstream.svg?color=blue)](https://pypi.org/project/types-aiobotocore-appstream)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-appstream.svg?color=blue)](https://pypi.org/project/types-aiobotocore-appstream)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-appstream?color=blue)](https://pypistats.org/packages/types-aiobotocore-appstream)

![boto3.typed](https://github.com/youtype/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[aiobotocore.AppStream 2.3.4](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appstream.html#AppStream)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 7.7.2](https://github.com/youtype/mypy_boto3_builder).

More information can be found on
[types-aiobotocore](https://pypi.org/project/types-aiobotocore/) page and in
[types-aiobotocore-appstream docs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_appstream/).

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/youtype/mypy_boto3_builder/raw/main/demo.gif)

- [types-aiobotocore-appstream](#types-aiobotocore-appstream)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [How to uninstall](#how-to-uninstall)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Emacs](#emacs)
    - [Sublime Text](#sublime-text)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [How it works](#how-it-works)
  - [What's new](#what's-new)
    - [Implemented features](#implemented-features)
    - [Latest changes](#latest-changes)
  - [Versioning](#versioning)
  - [Thank you](#thank-you)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `AppStream`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `AppStream` service.

```bash
# install with aiobotocore type annotations
python -m pip install 'types-aiobotocore[appstream]'


# Lite version does not provide session.client/resource overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'types-aiobotocore-lite[appstream]'


# standalone installation
python -m pip install types-aiobotocore-appstream
```

<a id="how-to-uninstall"></a>

## How to uninstall

```bash
python -m pip uninstall -y types-aiobotocore-appstream
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[appstream]` in your environment:

```bash
python -m pip install 'types-aiobotocore[appstream]'
```

Both type checking and code completion should now work. No explicit type
annotations required, write your `aiobotocore` code as usual.

<a id="pycharm"></a>

### PyCharm

Install `types-aiobotocore-lite[appstream]` in your environment:

```bash
python -m pip install 'types-aiobotocore-lite[appstream]'`
```

Both type checking and code completion should now work. Explicit type
annotations **are required**.

Use `types-aiobotocore` package instead for implicit type discovery.

<a id="emacs"></a>

### Emacs

- Install `types-aiobotocore` with services you use in your environment:

```bash
python -m pip install 'types-aiobotocore[appstream]'
```

- Install [use-package](https://github.com/jwiegley/use-package),
  [lsp](https://github.com/emacs-lsp/lsp-mode/),
  [company](https://github.com/company-mode/company-mode) and
  [flycheck](https://github.com/flycheck/flycheck) packages
- Install [lsp-pyright](https://github.com/emacs-lsp/lsp-pyright) package

```elisp
(use-package lsp-pyright
  :ensure t
  :hook (python-mode . (lambda ()
                          (require 'lsp-pyright)
                          (lsp)))  ; or lsp-deferred
  :init (when (executable-find "python3")
          (setq lsp-pyright-python-executable-cmd "python3"))
  )
```

- Make sure emacs uses the environment where you have installed
  `types-aiobotocore`

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="sublime-text"></a>

### Sublime Text

- Install `types-aiobotocore[appstream]` with services you use in your
  environment:

```bash
python -m pip install 'types-aiobotocore[appstream]'
```

- Install [LSP-pyright](https://github.com/sublimelsp/LSP-pyright) package

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[appstream]` in your environment:

```bash
python -m pip install 'types-aiobotocore[appstream]'`
```

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `npm i -g pyright`
- Install `types-aiobotocore[appstream]` in your environment:

```bash
python -m pip install 'types-aiobotocore[appstream]'
```

Optionally, you can install `types-aiobotocore` to `typings` folder.

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`AppStreamClient` provides annotations for
`session.create_client("appstream")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_appstream import AppStreamClient

session = get_session()
async with session.create_client("appstream") as client:
    client: AppStreamClient
    # now client usage is checked by mypy and IDE should provide code completion
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_appstream.paginator` module contains type annotations for
all paginators.

````python
from aiobotocore.session import get_session

from types_aiobotocore_appstream import AppStreamClient
from types_aiobotocore_appstream.paginator import (
    DescribeDirectoryConfigsPaginator,
    DescribeFleetsPaginator,
    DescribeImageBuildersPaginator,
    DescribeImagesPaginator,
    DescribeSessionsPaginator,
    DescribeStacksPaginator,
    DescribeUserStackAssociationsPaginator,
    DescribeUsersPaginator,
    ListAssociatedFleetsPaginator,
    ListAssociatedStacksPaginator,
)

session = get_session()
async with session.create_client("appstream") as client:
    client: AppStreamClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        describe_directory_configs_paginator: DescribeDirectoryConfigsPaginator = client.get_paginator("describe_directory_configs")
        describe_fleets_paginator: DescribeFleetsPaginator = client.get_paginator("describe_fleets")
        describe_image_builders_paginator: DescribeImageBuildersPaginator = client.get_paginator("describe_image_builders")
        describe_images_paginator: DescribeImagesPaginator = client.get_paginator("describe_images")
        describe_sessions_paginator: DescribeSessionsPaginator = client.get_paginator("describe_sessions")
        describe_stacks_paginator: DescribeStacksPaginator = client.get_paginator("describe_stacks")
        describe_user_stack_associations_paginator: DescribeUserStackAssociationsPaginator = client.get_paginator("describe_user_stack_associations")
        describe_users_paginator: DescribeUsersPaginator = client.get_paginator("describe_users")
        list_associated_fleets_paginator: ListAssociatedFleetsPaginator = client.get_paginator("list_associated_fleets")
        list_associated_stacks_paginator: ListAssociatedStacksPaginator = client.get_paginator("list_associated_stacks")
    ```


### Waiters annotations

`types_aiobotocore_appstream.waiter` module contains type annotations for all waiters.

```python
from aiobotocore.session import get_session

from types_aiobotocore_appstream.client import AppStreamClient
from types_aiobotocore_appstream.waiter import (
    FleetStartedWaiter,
    FleetStoppedWaiter,
)

session = get_session()
async with session.create_client("appstream") as client:
    client: AppStreamClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        fleet_started_waiter: FleetStartedWaiter = client.get_waiter("fleet_started")
        fleet_stopped_waiter: FleetStoppedWaiter = client.get_waiter("fleet_stopped")
    ```





<a id="literals"></a>

### Literals

`types_aiobotocore_appstream.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from types_aiobotocore_appstream.literals import (
    AccessEndpointTypeType,
    ActionType,
    AppVisibilityType,
    ApplicationAttributeType,
    AuthenticationTypeType,
    DescribeDirectoryConfigsPaginatorName,
    DescribeFleetsPaginatorName,
    DescribeImageBuildersPaginatorName,
    DescribeImagesPaginatorName,
    DescribeSessionsPaginatorName,
    DescribeStacksPaginatorName,
    DescribeUserStackAssociationsPaginatorName,
    DescribeUsersPaginatorName,
    FleetAttributeType,
    FleetErrorCodeType,
    FleetStartedWaiterName,
    FleetStateType,
    FleetStoppedWaiterName,
    FleetTypeType,
    ImageBuilderStateChangeReasonCodeType,
    ImageBuilderStateType,
    ImageStateChangeReasonCodeType,
    ImageStateType,
    ListAssociatedFleetsPaginatorName,
    ListAssociatedStacksPaginatorName,
    MessageActionType,
    PermissionType,
    PlatformTypeType,
    SessionConnectionStateType,
    SessionStateType,
    StackAttributeType,
    StackErrorCodeType,
    StorageConnectorTypeType,
    StreamViewType,
    UsageReportExecutionErrorCodeType,
    UsageReportScheduleType,
    UserStackAssociationErrorCodeType,
    VisibilityTypeType,
    AppStreamServiceName,
    ServiceName,
    ResourceServiceName,
    PaginatorName,
    WaiterName,
    RegionName,
)

def check_value(value: AccessEndpointTypeType) -> bool:
    ...
````

<a id="typed-dictionaries"></a>

### Typed dictionaries

`types_aiobotocore_appstream.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_appstream.type_defs import (
    AccessEndpointTypeDef,
    S3LocationTypeDef,
    ApplicationFleetAssociationTypeDef,
    ApplicationSettingsResponseTypeDef,
    ApplicationSettingsTypeDef,
    AssociateApplicationFleetRequestRequestTypeDef,
    ResponseMetadataTypeDef,
    AssociateApplicationToEntitlementRequestRequestTypeDef,
    AssociateFleetRequestRequestTypeDef,
    UserStackAssociationTypeDef,
    ComputeCapacityStatusTypeDef,
    ComputeCapacityTypeDef,
    CopyImageRequestRequestTypeDef,
    ServiceAccountCredentialsTypeDef,
    EntitlementAttributeTypeDef,
    DomainJoinInfoTypeDef,
    VpcConfigTypeDef,
    CreateImageBuilderStreamingURLRequestRequestTypeDef,
    StorageConnectorTypeDef,
    UserSettingTypeDef,
    CreateStreamingURLRequestRequestTypeDef,
    CreateUpdatedImageRequestRequestTypeDef,
    CreateUserRequestRequestTypeDef,
    DeleteAppBlockRequestRequestTypeDef,
    DeleteApplicationRequestRequestTypeDef,
    DeleteDirectoryConfigRequestRequestTypeDef,
    DeleteEntitlementRequestRequestTypeDef,
    DeleteFleetRequestRequestTypeDef,
    DeleteImageBuilderRequestRequestTypeDef,
    DeleteImagePermissionsRequestRequestTypeDef,
    DeleteImageRequestRequestTypeDef,
    DeleteStackRequestRequestTypeDef,
    DeleteUserRequestRequestTypeDef,
    DescribeAppBlocksRequestRequestTypeDef,
    DescribeApplicationFleetAssociationsRequestRequestTypeDef,
    DescribeApplicationsRequestRequestTypeDef,
    PaginatorConfigTypeDef,
    DescribeDirectoryConfigsRequestRequestTypeDef,
    DescribeEntitlementsRequestRequestTypeDef,
    WaiterConfigTypeDef,
    DescribeFleetsRequestRequestTypeDef,
    DescribeImageBuildersRequestRequestTypeDef,
    DescribeImagePermissionsRequestRequestTypeDef,
    DescribeImagesRequestRequestTypeDef,
    DescribeSessionsRequestRequestTypeDef,
    DescribeStacksRequestRequestTypeDef,
    DescribeUsageReportSubscriptionsRequestRequestTypeDef,
    DescribeUserStackAssociationsRequestRequestTypeDef,
    DescribeUsersRequestRequestTypeDef,
    UserTypeDef,
    DisableUserRequestRequestTypeDef,
    DisassociateApplicationFleetRequestRequestTypeDef,
    DisassociateApplicationFromEntitlementRequestRequestTypeDef,
    DisassociateFleetRequestRequestTypeDef,
    EnableUserRequestRequestTypeDef,
    EntitledApplicationTypeDef,
    ExpireSessionRequestRequestTypeDef,
    FleetErrorTypeDef,
    ImageBuilderStateChangeReasonTypeDef,
    NetworkAccessConfigurationTypeDef,
    ResourceErrorTypeDef,
    ImagePermissionsTypeDef,
    ImageStateChangeReasonTypeDef,
    LastReportGenerationExecutionErrorTypeDef,
    ListAssociatedFleetsRequestRequestTypeDef,
    ListAssociatedStacksRequestRequestTypeDef,
    ListEntitledApplicationsRequestRequestTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    StackErrorTypeDef,
    StartFleetRequestRequestTypeDef,
    StartImageBuilderRequestRequestTypeDef,
    StopFleetRequestRequestTypeDef,
    StopImageBuilderRequestRequestTypeDef,
    TagResourceRequestRequestTypeDef,
    UntagResourceRequestRequestTypeDef,
    ApplicationTypeDef,
    CreateApplicationRequestRequestTypeDef,
    ScriptDetailsTypeDef,
    UpdateApplicationRequestRequestTypeDef,
    AssociateApplicationFleetResultTypeDef,
    CopyImageResponseTypeDef,
    CreateImageBuilderStreamingURLResultTypeDef,
    CreateStreamingURLResultTypeDef,
    CreateUsageReportSubscriptionResultTypeDef,
    DescribeApplicationFleetAssociationsResultTypeDef,
    ListAssociatedFleetsResultTypeDef,
    ListAssociatedStacksResultTypeDef,
    ListTagsForResourceResponseTypeDef,
    BatchAssociateUserStackRequestRequestTypeDef,
    BatchDisassociateUserStackRequestRequestTypeDef,
    DescribeUserStackAssociationsResultTypeDef,
    UserStackAssociationErrorTypeDef,
    CreateDirectoryConfigRequestRequestTypeDef,
    DirectoryConfigTypeDef,
    UpdateDirectoryConfigRequestRequestTypeDef,
    CreateEntitlementRequestRequestTypeDef,
    EntitlementTypeDef,
    UpdateEntitlementRequestRequestTypeDef,
    CreateFleetRequestRequestTypeDef,
    CreateImageBuilderRequestRequestTypeDef,
    UpdateFleetRequestRequestTypeDef,
    CreateStackRequestRequestTypeDef,
    UpdateStackRequestRequestTypeDef,
    DescribeDirectoryConfigsRequestDescribeDirectoryConfigsPaginateTypeDef,
    DescribeFleetsRequestDescribeFleetsPaginateTypeDef,
    DescribeImageBuildersRequestDescribeImageBuildersPaginateTypeDef,
    DescribeImagesRequestDescribeImagesPaginateTypeDef,
    DescribeSessionsRequestDescribeSessionsPaginateTypeDef,
    DescribeStacksRequestDescribeStacksPaginateTypeDef,
    DescribeUserStackAssociationsRequestDescribeUserStackAssociationsPaginateTypeDef,
    DescribeUsersRequestDescribeUsersPaginateTypeDef,
    ListAssociatedFleetsRequestListAssociatedFleetsPaginateTypeDef,
    ListAssociatedStacksRequestListAssociatedStacksPaginateTypeDef,
    DescribeFleetsRequestFleetStartedWaitTypeDef,
    DescribeFleetsRequestFleetStoppedWaitTypeDef,
    DescribeUsersResultTypeDef,
    ListEntitledApplicationsResultTypeDef,
    FleetTypeDef,
    SessionTypeDef,
    ImageBuilderTypeDef,
    SharedImagePermissionsTypeDef,
    UpdateImagePermissionsRequestRequestTypeDef,
    UsageReportSubscriptionTypeDef,
    StackTypeDef,
    CreateApplicationResultTypeDef,
    DescribeApplicationsResultTypeDef,
    ImageTypeDef,
    UpdateApplicationResultTypeDef,
    AppBlockTypeDef,
    CreateAppBlockRequestRequestTypeDef,
    BatchAssociateUserStackResultTypeDef,
    BatchDisassociateUserStackResultTypeDef,
    CreateDirectoryConfigResultTypeDef,
    DescribeDirectoryConfigsResultTypeDef,
    UpdateDirectoryConfigResultTypeDef,
    CreateEntitlementResultTypeDef,
    DescribeEntitlementsResultTypeDef,
    UpdateEntitlementResultTypeDef,
    CreateFleetResultTypeDef,
    DescribeFleetsResultTypeDef,
    UpdateFleetResultTypeDef,
    DescribeSessionsResultTypeDef,
    CreateImageBuilderResultTypeDef,
    DeleteImageBuilderResultTypeDef,
    DescribeImageBuildersResultTypeDef,
    StartImageBuilderResultTypeDef,
    StopImageBuilderResultTypeDef,
    DescribeImagePermissionsResultTypeDef,
    DescribeUsageReportSubscriptionsResultTypeDef,
    CreateStackResultTypeDef,
    DescribeStacksResultTypeDef,
    UpdateStackResultTypeDef,
    CreateUpdatedImageResultTypeDef,
    DeleteImageResultTypeDef,
    DescribeImagesResultTypeDef,
    CreateAppBlockResultTypeDef,
    DescribeAppBlocksResultTypeDef,
)

def get_structure() -> AccessEndpointTypeDef:
    return {
      ...
    }
```

<a id="how-it-works"></a>

## How it works

Fully automated
[mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder) carefully
generates type annotations for each service, patiently waiting for
`aiobotocore` updates. It delivers a drop-in type annotations for you and makes
sure that:

- All available `aiobotocore` services are covered.
- Each public class and method of every `aiobotocore` service gets valid type
  annotations extracted from the documentation (blame `botocore` docs if types
  are incorrect).
- Type annotations include up-to-date documentation.
- Link to documentation is provided for every method.
- Code is processed by [black](https://github.com/psf/black) and
  [isort](https://github.com/PyCQA/isort) for readability.

<a id="what's-new"></a>

## What's new

<a id="implemented-features"></a>

### Implemented features

- Fully type annotated `boto3`, `botocore` and `aiobotocore` libraries
- `mypy`, `pyright`, `VSCode`, `PyCharm`, `Sublime Text` and `Emacs`
  compatibility
- `Client`, `ServiceResource`, `Resource`, `Waiter` `Paginator` type
  annotations for each service
- Generated `TypeDefs` for each service
- Generated `Literals` for each service
- Auto discovery of types for `boto3.client` and `boto3.session` calls
- Auto discovery of types for `session.client` and `session.session` calls
- Auto discovery of types for `client.get_waiter` and `client.get_paginator`
  calls
- Auto discovery of types for `ServiceResource` and `Resource` collections
- Auto discovery of types for `aiobotocore.Session.create_client` calls

<a id="latest-changes"></a>

### Latest changes

Builder changelog can be found in
[Releases](https://github.com/youtype/mypy_boto3_builder/releases).

<a id="versioning"></a>

## Versioning

`types-aiobotocore-appstream` version is the same as related `aiobotocore`
version and follows [PEP 440](https://www.python.org/dev/peps/pep-0440/)
format.

<a id="thank-you"></a>

## Thank you

- [Allie Fitter](https://github.com/alliefitter) for
  [boto3-type-annotations](https://pypi.org/project/boto3-type-annotations/),
  this package is based on top of his work
- [black](https://github.com/psf/black) developers for an awesome formatting
  tool
- [Timothy Edmund Crosley](https://github.com/timothycrosley) for
  [isort](https://github.com/PyCQA/isort) and how flexible it is
- [mypy](https://github.com/python/mypy) developers for doing all dirty work
  for us
- [pyright](https://github.com/microsoft/pyright) team for the new era of typed
  Python

<a id="documentation"></a>

## Documentation

All services type annotations can be found in
[aiobotocore docs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_appstream/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder/issues/)
repository.
